#
# spec file for package python-ConfigArgParse
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-ConfigArgParse
Version:        1.7
Release:        3.1
Summary:        A drop-in replacement for argparse
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/bw2/ConfigArgParse
Source:         https://files.pythonhosted.org/packages/source/C/ConfigArgParse/ConfigArgParse-%{version}.tar.gz
Patch1:         https://github.com/bw2/ConfigArgParse/pull/295/commits/c6a974211f1a13d492bb807ff6d07cefcc948a87.patch#/py313-tests.patch
Patch2:         https://github.com/bw2/ConfigArgParse/pull/295/commits/5e9f442374bc6d9707a43df13aaff684dff6b535.patch#/py313-skip-exit.patch
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-setuptools
# Old name of the package
Provides:       python-configargparse = %{version}-%{release}
Obsoletes:      python-configargparse < %{version}-%{release}
BuildArch:      noarch
%python_subpackages

%description
ConfigArgParse allows options to also be set via config files and/or environment
variables.

Applications with more than a handful of user-settable options are best configured
through a combination of command line args, config files, hard-coded defaults, and
in some cases, environment variables.

Python’s command line parsing modules such as argparse have very limited support
for config files and environment variables, so this module extends argparse to
add these features

%prep
%autosetup -p1 -n ConfigArgParse-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# https://github.com/bw2/ConfigArgParse/issues/146
export COLUMNS=80
%pytest -k 'not (test_main or testGlobalInstances or testGlobalInstances_WithName or testConfigOrEnvValueErrors or testMutuallyExclusiveArgs)'

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/configargparse*
%{python_sitelib}/[Cc]onfig[Aa]rg[Pp]arse-%{version}*info
%pycache_only %{python_sitelib}/__pycache__

%changelog
* Mon May  5 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Tue Oct 29 2024 Dirk Müller <dmueller@suse.com>
- add py313-skip-exit.patch, py313-tests.patch
- skip one more test
* Wed Jul 26 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7:
  * python 3.11 enablement
  * improved apidocs, improved README
* Sat Jul  1 2023 Dirk Müller <dmueller@suse.com>
- update to 1.5.5:
  * no upstream changelog available
* Mon Jun 12 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Mar  9 2022 pgajdos@suse.com
- version update to 1.5.3
  * no upstream changelog found
- python-mock actually not required for build
* Tue Jul 20 2021 Matej Cepl <mcepl@suse.com>
- Rename the package according to PyPI
* Sun Jul  4 2021 Dirk Müller <dmueller@suse.com>
- update to 1.5.1:
  * no changes file available
* Tue Jun  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Provide PyPi module name
* Mon Mar  8 2021 Dirk Müller <dmueller@suse.com>
- update to 1.3:
  * Python 3.9 support
* Wed Jun 10 2020 Matej Cepl <mcepl@suse.com>
- Remove unnecessary dependency on unittest2
* Mon Jun  1 2020 pgajdos@suse.com
- version update to 1.2.3
  * Fixes #179
  * allow use of nargs with action=append (#177)
  * Merged ConfigparserConfigFileParser - PR #173 - which adds support
    for python's Configparser config file format
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Thu Feb 20 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.0.
  * Dash supported as first char of argument
* Thu Nov 21 2019 Matej Cepl <mcepl@suse.com>
- When setting the environmental variable COLUMNS=80
  test case test_help_with_metavar works again.
  gh#bw2/ConfigArgParse#146
* Wed Oct 23 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.15.1
  * Drop support for EOL Python 2.6, 3.2-3.3
  * Add Python 3.6
  * sudo no longer needed
  * travis: Add latest Python versions.
  * Drop support for EOL Python 3.4
  * Fix DeprecationWarning: invalid escape sequence \[
- dropped skip-test.patch
  * https://github.com/bw2/ConfigArgParse/commit/6267759da55c87508394314292c6c5286220d99d
* Tue Sep 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip failing tests that were reported upstream with no reaction
* Fri Mar  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.14.0:
  * Fixes for python3.6 and 3.7
  * Various lint fixes
- Make sure we run tests
- add patch skip-test.patch that skips test that does not work
  in our test enviroment
* Fri May 18 2018 mcepl@suse.com
- Cleanup SPEC file and add check section
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Thu Dec 17 2015 jweberhofer@weberhofer.at
- Updated to version 0.10.0
  * config file syntax is now easier to override or extend using the new
    constructor arg: config_file_parser (via merged gh#bw2/ConfigArgParse#28 - thanks @lahwaacz )
  * support for python 2.6 (via merged gh#bw2/ConfigArgParse#18 - thanks @kuba )
  * replace dashes with underscores in env. var names when using the
    auto-env-var feature (via merged gh#bw2/ConfigArgParse#29 - thanks @helgi )
- Fixed download-link and homepage
- Fixed license
* Mon Mar  9 2015 freitag@owncloud.com
- Add LICENSE file to doc section of the package
- Use python-setuptools as dependency
- Use full link to source.
* Wed Mar  4 2015 freitag@owncloud.com
- Some minor cleanups.
* Wed Mar  4 2015 freitag@owncloud.com
- Update to upstream version 0.9.3 to make mitmproxy work.
* Tue Mar  3 2015 freitag@opensuse.org
- Initial package release
